==> humhub-1.0.1.tar.gz: humhub-1.0.1/protected/humhub/libs/CURLHelper.php <==
<?php

/**
 * @link https://www.humhub.org/
 * @copyright Copyright (c) 2015 HumHub GmbH & Co. KG
 * @license https://www.humhub.com/licences
 */

namespace humhub\libs;

use Yii;
use humhub\models\Setting;

/**
 * CURLHelper
 *
 * @author luke
 */
class CURLHelper
{

    /**
     * Returns CURL Default Options
     * 
     * @return array
     */
    public static function getOptions()
    {
        $options = array(
            CURLOPT_SSL_VERIFYPEER => (Yii::$app->params['curl']['validateSsl']) ? true : false,
            CURLOPT_SSL_VERIFYHOST => (Yii::$app->params['curl']['validateSsl']) ? 2 : 0,
            CURLOPT_REDIR_PROTOCOLS => CURLPROTO_HTTP | CURLPROTO_HTTPS,
            CURLOPT_PROTOCOLS => CURLPROTO_HTTP | CURLPROTO_HTTPS,
            CURLOPT_CAINFO => Yii::getAlias('@humhub/config/cacert.pem')
        );

        if (Setting::Get('enabled', 'proxy')) {
            $options[CURLOPT_PROXY] = Setting::Get('server', 'proxy');
            $options[CURLOPT_PROXYPORT] = Setting::Get('port', 'proxy');
            if (defined('CURLOPT_PROXYUSERNAME')) {
                $options[CURLOPT_PROXYUSERNAME] = Setting::Get('user', 'proxy');
            }
            if (defined('CURLOPT_PROXYPASSWORD')) {
                $options[CURLOPT_PROXYPASSWORD] = Setting::Get('password', 'proxy');
            }
            if (defined('CURLOPT_NOPROXY')) {
                $options[CURLOPT_NOPROXY] = Setting::Get('noproxy', 'proxy');
            }
        }

        return $options;
    }

}

==> humhub-1.2.1.tar.gz: humhub-1.2.1/protected/humhub/libs/CURLHelper.php <==
<?php

/**
 * @link https://www.humhub.org/
 * @copyright Copyright (c) 2017 HumHub GmbH & Co. KG
 * @license https://www.humhub.com/licences
 */

namespace humhub\libs;

use Yii;


/**
 * CURLHelper
 *
 * @author luke
 */
class CURLHelper
{

    /**
     * Returns CURL Default Options
     *
     * @return array
     */
    public static function getOptions()
    {
        $options = array(
            CURLOPT_SSL_VERIFYPEER => (Yii::$app->params['curl']['validateSsl']) ? true : false,
            CURLOPT_SSL_VERIFYHOST => (Yii::$app->params['curl']['validateSsl']) ? 2 : 0,
            CURLOPT_REDIR_PROTOCOLS => CURLPROTO_HTTP | CURLPROTO_HTTPS,
            CURLOPT_PROTOCOLS => CURLPROTO_HTTP | CURLPROTO_HTTPS,
            CURLOPT_CAINFO => Yii::getAlias('@humhub/config/cacert.pem')
        );

        if (Yii::$app->settings->get('proxy.enabled')) {
            $options[CURLOPT_PROXY] = Yii::$app->settings->get('proxy.server');
            $options[CURLOPT_PROXYPORT] = Yii::$app->settings->get('proxy.port');
            if (defined('CURLOPT_PROXYUSERNAME')) {
                $options[CURLOPT_PROXYUSERNAME] = Yii::$app->settings->get('proxy.user');
            }
            if (defined('CURLOPT_PROXYPASSWORD')) {
                $options[CURLOPT_PROXYPASSWORD] = Yii::$app->settings->get('proxy.password');
            }
            if (defined('CURLOPT_NOPROXY')) {
                $options[CURLOPT_NOPROXY] = Yii::$app->settings->get('proxy.noproxy');
            }
        }

        return $options;
    }

}
